/*
 * Copyright (C) 1999, 2000, 2001  Lorenzo Bettini, bettini@gnu.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

// base class for char translators

#ifndef _CHARTRANSLATOR_H
#define _CHARTRANSLATOR_H

#define NUM_OF_CHARS 256

#include <iostream>

using std::ostream;

class CharTranslator
{
 protected:
  char *characters[NUM_OF_CHARS];

 public:
  CharTranslator();

  void set_translation(char, const char *);
  virtual void translate(ostream *, const char *);
} ;

#endif // _CHARTRANSLATOR_H
